# PySink

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Zack Johnson

## Examples of How To Use (Buggy Alpha Version)

Setting up a basic Async App

```python
from PySink import hello_pysink

hello_pysink()
# Other Code

# When You Are Done
```


[//]: # (Check out: https://www.youtube.com/c/NeuralNine)